/*
	Combat and Stacking Overhaul
	Rules
	by Gedemon (2016)
*/
 
/* Version */
INSERT OR REPLACE INTO GlobalParameters (Name, Value) VALUES ('CSO_VERSION', 'Alpha .1');

-----------------------------------------------
-- Units
-----------------------------------------------

/* # types of units per tile (some checks to prevent more than 1UPT seems harcoded) */
UPDATE GlobalParameters SET Value = 1 WHERE Name = 'PLOT_UNIT_LIMIT';	-- default = 1

/* More units on map */
UPDATE Units SET Cost = Cost * 0.75 WHERE Cost > 1 AND (Domain = 'DOMAIN_LAND' or Domain = 'DOMAIN_SEA') AND NOT FormationClass = 'FORMATION_CLASS_CIVILIAN';
UPDATE Units SET Cost = Cost * 0.85 WHERE Cost > 1 AND (Domain = 'DOMAIN_AIR');
-- Balance : Combat bonus is less required if AI can put twice more units in an area as it already has a production bonus from difficulty
DELETE FROM Modifiers WHERE ModifierId ='HIGH_DIFFICULTY_COMBAT_SCALING'; 

/* AT are ranged support */
UPDATE Units SET Range ='1', PromotionClass ='PROMOTION_CLASS_RANGED' WHERE UnitType = 'UNIT_AT_CREW' OR UnitType = 'UNIT_MODERN_AT';
UPDATE Units SET RangedCombat ='65', Combat ='60' WHERE UnitType = 'UNIT_AT_CREW'; 		-- default Combat = 70
UPDATE Units SET RangedCombat ='75', Combat ='70' WHERE UnitType = 'UNIT_MODERN_AT';	-- default Combat = 80

/* Create new formation classes */
/*
-- Need DLL access to link FORMATION CLASS to a stacking class.
INSERT INTO Types (Type, Kind) VALUES ('FORMATION_CLASS_RANGED', 'KIND_FORMATION_CLASS');
INSERT INTO UnitFormationClasses (FormationClassType, Name) VALUES ('FORMATION_CLASS_RANGED', 'Ranged');

INSERT INTO Types (Type, Kind) VALUES ('FORMATION_CLASS_RECON', 'KIND_FORMATION_CLASS');
INSERT INTO UnitFormationClasses (FormationClassType, Name) VALUES ('FORMATION_CLASS_RECON', 'Recon');
*/

/* Apply the new classes (order is important !) */
UPDATE Units SET FormationClass = 'FORMATION_CLASS_SUPPORT' WHERE (RangedCombat > 0 OR Bombard > 0) AND (Domain = 'DOMAIN_LAND');
UPDATE Units SET FormationClass = 'FORMATION_CLASS_SUPPORT' WHERE PromotionClass = 'PROMOTION_CLASS_RECON' AND Domain = 'DOMAIN_LAND';

/* Apply new AI */
/*
-- to do ?
DELETE FROM UnitAiInfos WHERE UnitType = (SELECT UnitType FROM Units WHERE (RangedCombat > 0 OR Bombard > 0) AND (Domain = 'DOMAIN_LAND'));
*/
UPDATE UnitAiInfos SET AiType ='UNITTYPE_RANGED' WHERE AiType ='UNITTYPE_MELEE' AND (UnitType = 'UNIT_AT_CREW' OR UnitType = 'UNIT_MODERN_AT');
INSERT INTO UnitAiInfos 
(	UnitType, 				AiType) VALUES
(	'UNIT_AMERICAN_P51', 	'UNITTYPE_RANGED'),
(	'UNIT_BIPLANE', 		'UNITTYPE_RANGED'),
(	'UNIT_BOMBER', 			'UNITTYPE_RANGED'),
(	'UNIT_FIGHTER', 		'UNITTYPE_RANGED'),
(	'UNIT_JET_BOMBER', 		'UNITTYPE_RANGED'),
(	'UNIT_JET_FIGHTER', 	'UNITTYPE_RANGED');

/* Range = 1 for all Ranged Land/Sea unit */
UPDATE Units SET Range ='1' WHERE (RangedCombat > 0 OR Bombard > 0) AND (Domain = 'DOMAIN_LAND' OR Domain = 'DOMAIN_SEA');

/* Range = 2 for some units */
UPDATE Units SET Range ='2' WHERE UnitType = 'UNIT_BATTLESHIP' OR UnitType = 'UNIT_BRAZILIAN_MINAS_GERAES';

/* Range = 3 for some units */
UPDATE Units SET Range ='3' WHERE UnitType = 'UNIT_ROCKET_ARTILLERY';

/* Range = 4 for some units */
UPDATE Units SET Range ='4' WHERE UnitType = 'UNIT_MISSILE_CRUISER' OR UnitType = 'UNIT_NUCLEAR_SUBMARINE';

/* Balance */
UPDATE Units SET RangedCombat ='50' WHERE UnitType = 'UNIT_RANGER'; -- default RangedCombat = 60
UPDATE Units SET CanTrain ='0' WHERE UnitType = 'UNIT_OBSERVATION_BALLOON';

/* Air Combat */
UPDATE Districts SET AirSlots = 3 WHERE DistrictType = 'DISTRICT_CITY_CENTER';	-- default = 1
UPDATE Units SET PrereqDistrict = NULL Where PrereqDistrict = "DISTRICT_AERODROME";

UPDATE Units SET BaseSightRange = 3 Where UnitType = "UNIT_BIPLANE";		-- default = 4
UPDATE Units SET BaseSightRange = 4 Where UnitType = "UNIT_FIGHTER";		-- default = 4
UPDATE Units SET BaseSightRange = 4 Where UnitType = "UNIT_AMERICAN_P51";	-- default = 4
UPDATE Units SET BaseSightRange = 4 Where UnitType = "UNIT_BOMBER";			-- default = 4
UPDATE Units SET BaseSightRange = 5 Where UnitType = "UNIT_JET_FIGHTER";	-- default = 2 ???
UPDATE Units SET BaseSightRange = 5 Where UnitType = "UNIT_JET_BOMBER";		-- default = 2 ???

/* Battering Ram and Siege tower should upgrade */
INSERT OR REPLACE INTO UnitUpgrades (Unit, UpgradeUnit) VALUES ('UNIT_BATTERING_RAM','UNIT_MILITARY_ENGINEER');
INSERT OR REPLACE INTO UnitUpgrades (Unit, UpgradeUnit) VALUES ('UNIT_SIEGE_TOWER','UNIT_MILITARY_ENGINEER');
INSERT OR REPLACE INTO TypeTags (Type, Tag)	VALUES ('UNIT_MILITARY_ENGINEER', 'CLASS_SIEGE_TOWER');

-----------------------------------------------
-- Combats
-----------------------------------------------

/* lower damage */
UPDATE GlobalParameters SET Value = 12		WHERE Name = 'COMBAT_BASE_DAMAGE';		-- default = 24
UPDATE GlobalParameters SET Value = 6		WHERE Name = 'COMBAT_MAX_EXTRA_DAMAGE';	-- default = 12

/* lower healing */
UPDATE GlobalParameters SET Value = 15		WHERE Name = 'COMBAT_HEAL_CITY_GARRISON';		-- default = 20
UPDATE GlobalParameters SET Value = 5		WHERE Name = 'COMBAT_HEAL_CITY_OUTER_DEFENSES';	-- default = 10
UPDATE GlobalParameters SET Value = 3		WHERE Name = 'COMBAT_HEAL_LAND_ENEMY';			-- default = 5
UPDATE GlobalParameters SET Value = 10		WHERE Name = 'COMBAT_HEAL_LAND_FRIENDLY';		-- default = 15
UPDATE GlobalParameters SET Value = 5		WHERE Name = 'COMBAT_HEAL_LAND_NEUTRAL';		-- default = 10
UPDATE GlobalParameters SET Value = 0		WHERE Name = 'COMBAT_HEAL_NAVAL_ENEMY';			-- default = 0
UPDATE GlobalParameters SET Value = 15		WHERE Name = 'COMBAT_HEAL_NAVAL_FRIENDLY';		-- default = 20
UPDATE GlobalParameters SET Value = 3		WHERE Name = 'COMBAT_HEAL_NAVAL_NEUTRAL';		-- default = 0
UPDATE ModifierArguments SET Value = 10 	WHERE ModifierID = 'MEDIC_INCREASE_HEAL_RATE';	-- default = 20

/* Bombard vs Units & Ranged vs Districts */
UPDATE GlobalParameters SET Value = 7		WHERE Name = 'COMBAT_BOMBARD_VS_UNIT_STRENGTH_MODIFIER';	-- default = 17 -- Lower Bombard Combat Strenght vs units by this amount
UPDATE GlobalParameters SET Value = 14		WHERE Name = 'COMBAT_RANGED_VS_DISTRICT_STRENGTH_MODIFIER';	-- default = 17 -- Lower Ranged Combat Strenght vs districts by this amount

-- % of damage against wall:
--"COMBAT_DEFENSE_DAMAGE_PERCENT_BOMBARD","100"
--"COMBAT_DEFENSE_DAMAGE_PERCENT_MELEE","15"
--"COMBAT_DEFENSE_DAMAGE_PERCENT_RANGED","50"


/* Garrison (inner) & Outer Defense */

UPDATE GlobalParameters SET Value = 75		WHERE Name = 'COMBAT_CITY_RANGED_DAMAGE_THRESHOLD';	-- default = 50

UPDATE Districts SET HitPoints = 100 WHERE DistrictType = 'DISTRICT_CITY_CENTER';					-- default = 200
UPDATE ModifierArguments SET Value = 100 WHERE ModifierID = 'CIVIL_ENGINEERING_URBAN_DEFENSES';		-- default = 200 -- Civil Engineering removed to try to remove city ranged attack

UPDATE Buildings SET OuterDefenseHitPoints = 10 WHERE BuildingType ='BUILDING_PALACE';		-- default = 0
UPDATE Buildings SET OuterDefenseHitPoints = 20 WHERE BuildingType ='BUILDING_WALLS';		-- default = 50 -- Walls removed to try to remove city ranged attack
UPDATE Buildings SET OuterDefenseHitPoints = 30 WHERE BuildingType ='BUILDING_CASTLE';		-- default = 50
UPDATE Buildings SET OuterDefenseHitPoints = 40 WHERE BuildingType ='BUILDING_STAR_FORT';	-- default = 50

UPDATE Buildings SET OuterDefenseStrength = 2 WHERE BuildingType ='BUILDING_WALLS';		-- default = 2 -- Walls removed to try to remove city ranged attack
UPDATE Buildings SET OuterDefenseStrength = 2 WHERE BuildingType ='BUILDING_CASTLE';	-- default = 2
UPDATE Buildings SET OuterDefenseStrength = 2 WHERE BuildingType ='BUILDING_STAR_FORT';	-- default = 2


-----------------------------------------------
-- Resources
-----------------------------------------------

/* Remove all resources requirements */
UPDATE Units SET StrategicResource = NULL;
UPDATE Projects SET PrereqResource = NULL;

/* Add bonuses for strategic resources */

INSERT INTO Tags
(	Tag,							Vocabulary		)	VALUES
(	'CLASS_GUNPOWDER',			'ABILITY_CLASS'		),
(	'CLASS_STEAM_ENGINE',		'ABILITY_CLASS'		),
(	'CLASS_COMBUSTION',			'ABILITY_CLASS'		),
(	'CLASS_COMBUSTION_AIR',		'ABILITY_CLASS'		),
(	'CLASS_NUCLEAR_POWERED',	'ABILITY_CLASS'		);

INSERT INTO TypeTags
(	Type,							Tag							)	VALUES

(	'UNIT_MUSKETMAN',				'CLASS_GUNPOWDER'			),
(	'UNIT_BOMBARD',					'CLASS_GUNPOWDER'			),
(	'UNIT_CHINESE_CROUCHING_TIGER',	'CLASS_GUNPOWDER'			),
(	'UNIT_SPANISH_CONQUISTADOR',	'CLASS_GUNPOWDER'			),
(	'UNIT_CARAVEL',               	'CLASS_GUNPOWDER'			),
(	'UNIT_FRIGATE',               	'CLASS_GUNPOWDER'			),
(	'UNIT_PRIVATEER',             	'CLASS_GUNPOWDER'			),
(	'UNIT_ENGLISH_SEADOG',        	'CLASS_GUNPOWDER'			),
(	'UNIT_FIELD_CANNON',          	'CLASS_GUNPOWDER'			),
(	'UNIT_CAVALRY',               	'CLASS_GUNPOWDER'			),
(	'UNIT_RUSSIAN_COSSACK',       	'CLASS_GUNPOWDER'			),
(	'UNIT_ENGLISH_REDCOAT',       	'CLASS_GUNPOWDER'			),
(	'UNIT_FRENCH_GARDE_IMPERIALE',	'CLASS_GUNPOWDER'			),
(	'UNIT_IRONCLAD',				'CLASS_GUNPOWDER'			),
(	'UNIT_RANGER',					'CLASS_GUNPOWDER'			),
(	'UNIT_BIPLANE',					'CLASS_COMBUSTION_AIR'		),
(	'UNIT_FIGHTER',					'CLASS_COMBUSTION_AIR'		),
(	'UNIT_AMERICAN_P51',			'CLASS_COMBUSTION_AIR'		),
(	'UNIT_BOMBER',					'CLASS_COMBUSTION_AIR'		),
(	'UNIT_JET_FIGHTER',				'CLASS_COMBUSTION_AIR'		),
(	'UNIT_JET_BOMBER',				'CLASS_COMBUSTION_AIR'		),
(	'UNIT_BIPLANE',					'CLASS_COMBUSTION'			),
(	'UNIT_FIGHTER',					'CLASS_COMBUSTION'			),
(	'UNIT_AMERICAN_P51',			'CLASS_COMBUSTION'			),
(	'UNIT_BOMBER',					'CLASS_COMBUSTION'			),
(	'UNIT_JET_FIGHTER',				'CLASS_COMBUSTION'			),
(	'UNIT_JET_BOMBER',				'CLASS_COMBUSTION'			),
(	'UNIT_TANK',					'CLASS_COMBUSTION'			),
(	'UNIT_HELICOPTER',				'CLASS_COMBUSTION'			),
(	'UNIT_MECHANIZED_INFANTRY',		'CLASS_COMBUSTION'			),
(	'UNIT_ROCKET_ARTILLERY',		'CLASS_COMBUSTION'			),
(	'UNIT_MOBILE_SAM',				'CLASS_COMBUSTION'			),
(	'UNIT_MODERN_ARMOR',			'CLASS_COMBUSTION'			),
(	'UNIT_BATTLESHIP',				'CLASS_COMBUSTION'			),
(	'UNIT_BRAZILIAN_MINAS_GERAES',	'CLASS_COMBUSTION'			),
(	'UNIT_SUBMARINE',				'CLASS_COMBUSTION'			),
(	'UNIT_GERMAN_UBOAT',			'CLASS_COMBUSTION'			),
(	'UNIT_AIRCRAFT_CARRIER',		'CLASS_COMBUSTION'			),
(	'UNIT_DESTROYER',				'CLASS_COMBUSTION'			),
(	'UNIT_MISSILE_CRUISER',			'CLASS_COMBUSTION'			),
(	'UNIT_IRONCLAD',				'CLASS_STEAM_ENGINE'		),
(	'UNIT_NUCLEAR_SUBMARINE',		'CLASS_NUCLEAR_POWERED'		);

INSERT INTO TraitModifiers
(	TraitType,					ModifierId												)	VALUES
-- Units production modifiers
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_SWORDSMAN'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_KNIGHT'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_CAVALRY'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HORSEMAN'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_KNIGHT'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_IRONCLAD'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_TANK'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_DESTROYER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_SUBMARINE'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR'		),
-- Units upgrade modifiers
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_IRON_BONUS_FOR_KNIGHT'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_CAVALRY'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_KNIGHT'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_TANK'					),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_DESTROYER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR'			),
-- Units purchase modifiers
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_IRON_BONUS_FOR_KNIGHT'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_CAVALRY'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_KNIGHT'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_TANK'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_DESTROYER'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE'	),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER'		),
(	'TRAIT_LEADER_MAJOR_CIV',	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR'		),
-- Units combat modifiers
(	'TRAIT_LEADER_MAJOR_CIV',	'UNIT_COMBAT_RESOURCE_NITER_BONUS'						),
-- Projects production modifiers		
(	'TRAIT_LEADER_MAJOR_CIV',	'NUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'THERMONUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'MANHATTAN_PROJECT_PRODUCTION_URANIUM_BONUS'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'OPERATION_IVY_PRODUCTION_URANIUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'EARTH_SATELLITE_PRODUCTION_ALUMINUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'MOON_LANDING_PRODUCTION_ALUMINUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'MARS_HABITATION_PRODUCTION_ALUMINUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'MARS_HYDROPONICS_PRODUCTION_ALUMINUM_BONUS'			),
(	'TRAIT_LEADER_MAJOR_CIV',	'MARS_REACTOR_PRODUCTION_ALUMINUM_BONUS'				),
(	'TRAIT_LEADER_MAJOR_CIV',	'MARS_REACTOR_PRODUCTION_URANIUM_BONUS'					),
-- Units movement modifiers
(	'TRAIT_LEADER_MAJOR_CIV',	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS'					),
(	'TRAIT_LEADER_MAJOR_CIV',	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS'						),
(	'TRAIT_LEADER_MAJOR_CIV',	'UNITS_RANGE_RESOURCE_OIL_BONUS'						),
(	'TRAIT_LEADER_MAJOR_CIV',	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS'					);

INSERT INTO TechnologyModifiers
(	TechnologyType,				ModifierId										)	VALUES
(	'TECH_CHEMISTRY',			'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS'			);

INSERT INTO Modifiers
(	ModifierId,												ModifierType,											RunOnce,	Permanent,	SubjectRequirementSetId,			OwnerRequirementSetId				)	VALUES

(	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS',				'MODIFIER_PLAYER_CITIES_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_NITER'		), -- MODIFIER_ALL_PLAYERS_ATTACH_MODIFIER | MODIFIER_ALL_CITIES_ATTACH_MODIFIER 
(	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS_MODIFIER',		'MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD',			'0',		'0',		'REQUIREMENTS_PLOT_HAS_FARM',		NULL								), -- MODIFIER_PLAYER_ADJUST_PLOT_YIELD | MODIFIER_CITY_PLOT_YIELDS_ADJUST_PLOT_YIELD | MODIFIER_SINGLE_PLOT_ADJUST_PLOT_YIELDS

(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_KNIGHT',			'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',	'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',	'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',	'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_TANK',				'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_DESTROYER',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE','MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'MODIFIER_PLAYER_UNITS_ADJUST_UNIT_PRODUCTION',			'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),

(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',				'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_TANK',				'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',		'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'MODIFIER_PLAYER_ADJUST_UNIT_UPGRADE_DISCOUNT_PERCENT',	'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),

(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_IRON'		),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_HORSES'		),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_TANK',				'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'MODIFIER_PLAYER_CITIES_ADJUST_UNIT_PURCHASE_COST',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_STEEL'		),

(	'UNIT_COMBAT_RESOURCE_NITER_BONUS',						'MODIFIER_PLAYER_UNITS_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_NITER'		),
(	'UNIT_COMBAT_RESOURCE_NITER_BONUS_MODIFIER',			'MODIFIER_UNIT_ADJUST_COMBAT_STRENGTH',					'0',		'0',		NULL,								'REQUIREMENT_UNITS_GUNPOWDER'		),
	
(	'NUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',				'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),
(	'THERMONUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',		'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),
(	'MANHATTAN_PROJECT_PRODUCTION_URANIUM_BONUS',			'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),
(	'OPERATION_IVY_PRODUCTION_URANIUM_BONUS',				'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),
(	'EARTH_SATELLITE_PRODUCTION_ALUMINUM_BONUS',			'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'MOON_LANDING_PRODUCTION_ALUMINUM_BONUS',				'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'MARS_HABITATION_PRODUCTION_ALUMINUM_BONUS',			'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'MARS_HYDROPONICS_PRODUCTION_ALUMINUM_BONUS',			'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'MARS_REACTOR_PRODUCTION_ALUMINUM_BONUS',				'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_ALUMINUM'	),
(	'MARS_REACTOR_PRODUCTION_URANIUM_BONUS',				'MODIFIER_PLAYER_CITIES_ADJUST_PROJECT_PRODUCTION',		'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),

(	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS',					'MODIFIER_PLAYER_UNITS_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_COAL'		),
(	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS_MODIFIER',			'MODIFIER_PLAYER_UNIT_ADJUST_MOVEMENT',					'0',		'0',		NULL,								'REQUIREMENT_UNITS_STEAM_ENGINE'	),
(	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS',					'MODIFIER_PLAYER_UNITS_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_OIL'		),
(	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS_MODIFIER',			'MODIFIER_PLAYER_UNIT_ADJUST_MOVEMENT',					'0',		'0',		NULL,								'REQUIREMENT_UNITS_COMBUSTION'		),
(	'UNITS_RANGE_RESOURCE_OIL_BONUS',						'MODIFIER_PLAYER_UNITS_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_OIL'		),
(	'UNITS_RANGE_RESOURCE_OIL_BONUS_MODIFIER',				'MODIFIER_UNIT_ADJUST_ATTACK_RANGE',					'0',		'0',		NULL,								'REQUIREMENT_UNITS_COMBUSTION_AIR'	),
(	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS',				'MODIFIER_PLAYER_UNITS_ATTACH_MODIFIER',				'0',		'0',		NULL,								'REQUIREMENT_PLAYER_HAS_URANIUM'	),
(	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS_MODIFIER',		'MODIFIER_PLAYER_UNIT_ADJUST_MOVEMENT',					'0',		'0',		NULL,								'REQUIREMENT_UNITS_NUCLEAR_POWERED'	);


INSERT INTO ModifierStrings
(	ModifierId,										Context,		Text						)	VALUES
(	'UNIT_COMBAT_RESOURCE_NITER_BONUS_MODIFIER',	'Preview',		'LOC_COMBAT_BONUS_NITER'	);


INSERT INTO ModifierArguments
(	ModifierId,											Name,			Value								)	VALUES

(	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS',				'ModifierId',	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS_MODIFIER'	),
(	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS_MODIFIER',		'YieldType',	'YIELD_FOOD'										),
(	'CHEMISTRY_ALLOWS_NITER_TO_FERTILIZERS_MODIFIER',		'Amount',		'1'													),
	
(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'UnitType',		'UNIT_SWORDSMAN'									),
(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_KNIGHT',			'UnitType',		'UNIT_KNIGHT'										),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'UnitType',		'UNIT_CAVALRY'										),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',		'UnitType',		'UNIT_HORSEMAN'										),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',	'UnitType',		'UNIT_HEAVY_CHARIOT'								),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'UnitType',		'UNIT_KNIGHT'										),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',		'UnitType',		'UNIT_FIGHTER'										),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',		'UnitType',		'UNIT_BOMBER'										),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',	'UnitType',		'UNIT_JET_FIGHTER'									),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',	'UnitType',		'UNIT_JET_BOMBER'									),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'UnitType',		'UNIT_IRONCLAD'										),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',		'UnitType',		'UNIT_BATTLESHIP'									),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_TANK',				'UnitType',		'UNIT_TANK'											),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'UnitType',		'UNIT_AIRCRAFT_CARRIER'								),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_DESTROYER',		'UnitType',		'UNIT_DESTROYER'									),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',		'UnitType',		'UNIT_SUBMARINE'									),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE','UnitType',		'UNIT_NUCLEAR_SUBMARINE'							),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'UnitType',		'UNIT_MISSILE_CRUISER'								),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'UnitType',		'UNIT_MODERN_ARMOR'									),
(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_IRON_BONUS_FOR_KNIGHT',			'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',	'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',	'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',	'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_TANK',				'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_DESTROYER',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',		'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE','Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'Amount',		'100'												),
(	'PRODUCTION_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'Amount',		'100'												),
	
(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'UnitType',		'UNIT_SWORDSMAN'									),
(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'UnitType',		'UNIT_KNIGHT'										),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'UnitType',		'UNIT_CAVALRY'										),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'UnitType',		'UNIT_HORSEMAN'										),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'UnitType',		'UNIT_HEAVY_CHARIOT'								),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',				'UnitType',		'UNIT_KNIGHT'										),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'UnitType',		'UNIT_FIGHTER'										),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'UnitType',		'UNIT_BOMBER'										),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'UnitType',		'UNIT_JET_FIGHTER'									),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'UnitType',		'UNIT_JET_BOMBER'									),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'UnitType',		'UNIT_IRONCLAD'										),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'UnitType',		'UNIT_BATTLESHIP'									),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_TANK',				'UnitType',		'UNIT_TANK'											),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'UnitType',		'UNIT_AIRCRAFT_CARRIER'								),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'UnitType',		'UNIT_DESTROYER'									),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'UnitType',		'UNIT_SUBMARINE'									),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'UnitType',		'UNIT_NUCLEAR_SUBMARINE'							),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',		'UnitType',		'UNIT_MISSILE_CRUISER'								),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'UnitType',		'UNIT_MODERN_ARMOR'									),
(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'Amount',		'25'												),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'Amount',		'50'												),
(	'UPGRADE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',				'Amount',		'25'												),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'Amount',		'50'												),
(	'UPGRADE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_TANK',				'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',		'Amount',		'50'												),
(	'UPGRADE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'Amount',		'50'												),
	
(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'UnitType',		'UNIT_SWORDSMAN'									),
(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'UnitType',		'UNIT_KNIGHT'										),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'UnitType',		'UNIT_CAVALRY'										),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'UnitType',		'UNIT_HORSEMAN'										),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'UnitType',		'UNIT_HEAVY_CHARIOT'								),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'UnitType',		'UNIT_KNIGHT'										),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'UnitType',		'UNIT_FIGHTER'										),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'UnitType',		'UNIT_BOMBER'										),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'UnitType',		'UNIT_JET_FIGHTER'									),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'UnitType',		'UNIT_JET_BOMBER'									),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'UnitType',		'UNIT_IRONCLAD'										),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'UnitType',		'UNIT_BATTLESHIP'									),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_TANK',				'UnitType',		'UNIT_TANK'											),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'UnitType',		'UNIT_AIRCRAFT_CARRIER'								),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'UnitType',		'UNIT_DESTROYER'									),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'UnitType',		'UNIT_SUBMARINE'									),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'UnitType',		'UNIT_NUCLEAR_SUBMARINE'							),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'UnitType',		'UNIT_MISSILE_CRUISER'								),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'UnitType',		'UNIT_MODERN_ARMOR'									),
(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_SWORDSMAN',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_IRON_BONUS_FOR_KNIGHT',				'Amount',		'25'												),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_CAVALRY',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HORSEMAN',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_HEAVY_CHARIOT',		'Amount',		'50'												),
(	'PURCHASE_RESOURCE_HORSES_BONUS_FOR_KNIGHT',			'Amount',		'25'												),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_FIGHTER',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_BOMBER',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_FIGHTER',		'Amount',		'50'												),
(	'PURCHASE_RESOURCE_ALUMINUM_BONUS_FOR_JET_BOMBER',		'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_IRONCLAD',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_BATTLESHIP',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_TANK',				'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_AIRCRAFT_CARRIER',	'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_DESTROYER',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_SUBMARINE',			'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_NUCLEAR_SUBMARINE',	'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MISSILE_CRUISER',	'Amount',		'50'												),
(	'PURCHASE_RESOURCE_STEEL_BONUS_FOR_MODERN_ARMOR',		'Amount',		'50'												),
				
(	'UNIT_COMBAT_RESOURCE_NITER_BONUS',						'ModifierId',	'UNIT_COMBAT_RESOURCE_NITER_BONUS_MODIFIER'			),
(	'UNIT_COMBAT_RESOURCE_NITER_BONUS_MODIFIER',			'Amount',		'5'													),
						
(	'NUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',				'ProjectType',	'PROJECT_BUILD_NUCLEAR_DEVICE'						),	
(	'THERMONUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',		'ProjectType',	'PROJECT_BUILD_THERMONUCLEAR_DEVICE'				),
(	'MANHATTAN_PROJECT_PRODUCTION_URANIUM_BONUS',			'ProjectType',	'PROJECT_MANHATTAN_PROJECT'							),
(	'OPERATION_IVY_PRODUCTION_URANIUM_BONUS',				'ProjectType',	'PROJECT_OPERATION_IVY'								),
(	'NUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',				'Amount',		'200'												),
(	'THERMONUCLEAR_DEVICE_PRODUCTION_URANIUM_BONUS',		'Amount',		'200'												),
(	'MANHATTAN_PROJECT_PRODUCTION_URANIUM_BONUS',			'Amount',		'100'												),
(	'OPERATION_IVY_PRODUCTION_URANIUM_BONUS',				'Amount',		'100'												),	

(	'EARTH_SATELLITE_PRODUCTION_ALUMINUM_BONUS',			'ProjectType',	'PROJECT_LAUNCH_EARTH_SATELLITE'					),	
(	'MOON_LANDING_PRODUCTION_ALUMINUM_BONUS',				'ProjectType',	'PROJECT_LAUNCH_MOON_LANDING'						),
(	'MARS_HABITATION_PRODUCTION_ALUMINUM_BONUS',			'ProjectType',	'PROJECT_LAUNCH_MARS_HABITATION'					),
(	'MARS_HYDROPONICS_PRODUCTION_ALUMINUM_BONUS',			'ProjectType',	'PROJECT_LAUNCH_MARS_HYDROPONICS'					),
(	'MARS_REACTOR_PRODUCTION_ALUMINUM_BONUS',				'ProjectType',	'PROJECT_LAUNCH_MARS_REACTOR'						),
(	'MARS_REACTOR_PRODUCTION_URANIUM_BONUS',				'ProjectType',	'PROJECT_LAUNCH_MARS_REACTOR'						),
(	'EARTH_SATELLITE_PRODUCTION_ALUMINUM_BONUS',			'Amount',		'100'												),
(	'MOON_LANDING_PRODUCTION_ALUMINUM_BONUS',				'Amount',		'100'												),
(	'MARS_HABITATION_PRODUCTION_ALUMINUM_BONUS',			'Amount',		'100'												),
(	'MARS_HYDROPONICS_PRODUCTION_ALUMINUM_BONUS',			'Amount',		'100'												),
(	'MARS_REACTOR_PRODUCTION_ALUMINUM_BONUS',				'Amount',		'100'												),
(	'MARS_REACTOR_PRODUCTION_URANIUM_BONUS',				'Amount',		'100'												),					
							
(	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS',					'ModifierId',	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS_MODIFIER'		),
(	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS_MODIFIER',			'Tag',			'CLASS_STEAM_ENGINE'								),
(	'UNITS_MOVEMENT_RESOURCE_COAL_BONUS_MODIFIER',			'Amount',		'1'													),
	
(	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS',					'ModifierId',	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS_MODIFIER'		),
(	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS_MODIFIER',			'Tag',			'CLASS_COMBUSTION'									),
(	'UNITS_MOVEMENT_RESOURCE_OIL_BONUS_MODIFIER',			'Amount',		'1'													),
	
(	'UNITS_RANGE_RESOURCE_OIL_BONUS',						'ModifierId',	'UNITS_RANGE_RESOURCE_OIL_BONUS_MODIFIER'			),
(	'UNITS_RANGE_RESOURCE_OIL_BONUS_MODIFIER',				'Tag',			'CLASS_COMBUSTION_AIR'								),
(	'UNITS_RANGE_RESOURCE_OIL_BONUS_MODIFIER',				'Amount',		'1'													),
	
(	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS',				'ModifierId',	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS_MODIFIER'	),
(	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS_MODIFIER',		'Tag',			'CLASS_NUCLEAR_POWERED'								),
(	'UNITS_MOVEMENT_RESOURCE_URANIUM_BONUS_MODIFIER',		'Amount',		'2'													);

INSERT INTO RequirementSets
(	RequirementSetId,						RequirementSetType			)	VALUES
(	'REQUIREMENT_PLAYER_HAS_IRON',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_HORSES',		'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_OIL',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_URANIUM',		'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_ALUMINUM',		'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_COAL',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_STEEL',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_PLAYER_HAS_NITER',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_UNITS_GUNPOWDER',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_UNITS_STEAM_ENGINE',		'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_UNITS_COMBUSTION',			'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_UNITS_COMBUSTION_AIR',		'REQUIREMENTSET_TEST_ALL'	),
(	'REQUIREMENT_UNITS_NUCLEAR_POWERED',	'REQUIREMENTSET_TEST_ALL'	);

INSERT INTO RequirementSetRequirements
(	RequirementSetId,						RequirementId						)	VALUES
(	'REQUIREMENT_PLAYER_HAS_IRON',			'REQUIRES_PLAYER_HAS_IRON'		),
(	'REQUIREMENT_PLAYER_HAS_HORSES',		'REQUIRES_PLAYER_HAS_HORSES'	),
(	'REQUIREMENT_PLAYER_HAS_OIL',			'REQUIRES_PLAYER_HAS_OIL'		),
(	'REQUIREMENT_PLAYER_HAS_URANIUM',		'REQUIRES_PLAYER_HAS_URANIUM'	),
(	'REQUIREMENT_PLAYER_HAS_ALUMINUM',		'REQUIRES_PLAYER_HAS_ALUMINUM'	),
(	'REQUIREMENT_PLAYER_HAS_COAL',			'REQUIRES_PLAYER_HAS_COAL'		),
(	'REQUIREMENT_PLAYER_HAS_STEEL',			'REQUIRES_PLAYER_HAS_COAL'		),
(	'REQUIREMENT_PLAYER_HAS_STEEL',			'REQUIRES_PLAYER_HAS_IRON'		),
(	'REQUIREMENT_PLAYER_HAS_NITER',			'REQUIRES_PLAYER_HAS_NITER'		),
(	'REQUIREMENT_UNITS_GUNPOWDER',			'REQUIRES_UNIT_GUNPOWDER'		),
(	'REQUIREMENT_UNITS_STEAM_ENGINE',		'REQUIRES_UNIT_STEAM_ENGINE'	),
(	'REQUIREMENT_UNITS_COMBUSTION',			'REQUIRES_UNIT_COMBUSTION'		),
(	'REQUIREMENT_UNITS_COMBUSTION_AIR',		'REQUIRES_UNIT_COMBUSTION_AIR'	),
(	'REQUIREMENT_UNITS_NUCLEAR_POWERED',	'REQUIRES_UNIT_NUCLEAR_POWERED'	);

INSERT INTO Requirements 
(	RequirementId,						RequirementType							)	VALUES
(	'REQUIRES_PLAYER_HAS_IRON',			'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_HORSES',		'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_OIL',			'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_URANIUM',		'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_ALUMINUM',		'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_COAL',			'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_PLAYER_HAS_NITER',		'REQUIREMENT_PLAYER_HAS_RESOURCE_OWNED'	),
(	'REQUIRES_UNIT_GUNPOWDER',			'REQUIREMENT_UNIT_TAG_MATCHES'			),
(	'REQUIRES_UNIT_STEAM_ENGINE',		'REQUIREMENT_UNIT_TAG_MATCHES'			),
(	'REQUIRES_UNIT_COMBUSTION',			'REQUIREMENT_UNIT_TAG_MATCHES'			),
(	'REQUIRES_UNIT_COMBUSTION_AIR',		'REQUIREMENT_UNIT_TAG_MATCHES'			),
(	'REQUIRES_UNIT_NUCLEAR_POWERED',	'REQUIREMENT_UNIT_TAG_MATCHES'			);

INSERT INTO RequirementArguments
(	RequirementId,						Name,				Value					)	VALUES
(	'REQUIRES_PLAYER_HAS_IRON',			'ResourceType',		'RESOURCE_IRON'			),
(	'REQUIRES_PLAYER_HAS_HORSES',		'ResourceType',		'RESOURCE_HORSES'		),
(	'REQUIRES_PLAYER_HAS_OIL',			'ResourceType',		'RESOURCE_OIL'			),
(	'REQUIRES_PLAYER_HAS_URANIUM',		'ResourceType',		'RESOURCE_URANIUM'		),
(	'REQUIRES_PLAYER_HAS_ALUMINUM',		'ResourceType',		'RESOURCE_ALUMINUM'		),
(	'REQUIRES_PLAYER_HAS_COAL',			'ResourceType',		'RESOURCE_COAL'			),
(	'REQUIRES_PLAYER_HAS_NITER',		'ResourceType',		'RESOURCE_NITER'		),
(	'REQUIRES_UNIT_GUNPOWDER',			'Tag',				'CLASS_GUNPOWDER'		),
(	'REQUIRES_UNIT_STEAM_ENGINE',		'Tag',				'CLASS_STEAM_ENGINE'	),
(	'REQUIRES_UNIT_COMBUSTION',			'Tag',				'CLASS_COMBUSTION'		),
(	'REQUIRES_UNIT_COMBUSTION_AIR',		'Tag',				'CLASS_COMBUSTION_AIR'	),
(	'REQUIRES_UNIT_NUCLEAR_POWERED',	'Tag',				'CLASS_NUCLEAR_POWERED'	);

/* Raise base cost of units receiving bonuses from strategic resources */
UPDATE Units SET Cost = Cost*2 
	WHERE 	UnitType = 'UNIT_SWORDSMAN'
	OR 		UnitType = 'UNIT_HORSEMAN'
	OR 		UnitType = 'UNIT_HEAVY_CHARIOT'
	OR 		UnitType = 'UNIT_CAVALRY'
	OR 		UnitType = 'UNIT_IRONCLAD'	
	OR 		UnitType = 'UNIT_BATTLESHIP'			
	OR 		UnitType = 'UNIT_TANK'				
	OR 		UnitType = 'UNIT_AIRCRAFT_CARRIER'	
	OR 		UnitType = 'UNIT_DESTROYER'			
	OR 		UnitType = 'UNIT_SUBMARINE'			
	OR 		UnitType = 'UNIT_NUCLEAR_SUBMARINE'	
	OR 		UnitType = 'UNIT_MISSILE_CRUISER'		
	OR 		UnitType = 'UNIT_MODERN_ARMOR'	
	OR 		UnitType = 'UNIT_FIGHTER'				
	OR 		UnitType = 'UNIT_BOMBER'				
	OR 		UnitType = 'UNIT_JET_FIGHTER'			
	OR 		UnitType = 'UNIT_JET_BOMBER';	
	
UPDATE Units SET Cost = Cost*3 -- Knight can get 2x 100% bonus (iron and horse)
	WHERE 		UnitType = 'UNIT_KNIGHT'; 
	
UPDATE Projects SET Cost = Cost*2 
	WHERE 	ProjectType = 'PROJECT_OPERATION_IVY'
	OR 		ProjectType = 'PROJECT_MANHATTAN_PROJECT';
	
UPDATE Projects SET Cost = Cost*3 -- 200% bonus from uranium, normal cost with, x3 without
	WHERE 	ProjectType = 'PROJECT_BUILD_NUCLEAR_DEVICE'
	OR 		ProjectType = 'PROJECT_BUILD_THERMONUCLEAR_DEVICE';
	
UPDATE Projects SET Cost = Cost*2 
	WHERE 	ProjectType = 'PROJECT_LAUNCH_EARTH_SATELLITE'
	OR 		ProjectType = 'PROJECT_LAUNCH_MOON_LANDING'	
	OR 		ProjectType = 'PROJECT_LAUNCH_MARS_HABITATION'
	OR 		ProjectType = 'PROJECT_LAUNCH_MARS_HYDROPONICS';
	
UPDATE Projects SET Cost = Cost*3 -- Mars Reactor can get 2x 100% bonus (aluminum and uranium)
	WHERE 	ProjectType = 'PROJECT_LAUNCH_MARS_REACTOR';

	
/* 
	TESTING SECTION
*/
/*


-----------------------------------------------
-- City Ranged Attack
-----------------------------------------------

/* 
	Thanks to hardcoding, range can't be changed and removing Outer Defense seems to be the only way to disable city ranged attack...
*/
/* Remove Walls */
/*
DELETE FROM Buildings WHERE BuildingType ='BUILDING_WALLS';
DELETE FROM BuildingPrereqs WHERE Building ='BUILDING_WALLS' or PrereqBuilding ='BUILDING_WALLS';
DELETE FROM ModifierArguments WHERE Value ='BUILDING_WALLS';
--*/

/*
-- Replacement lacks icons and 3D models
INSERT OR REPLACE INTO Types (Type, Kind) VALUES ('BUILDING_ANCIENT_WALLS','KIND_BUILDING');
INSERT OR REPLACE INTO Buildings VALUES('BUILDING_ANCIENT_WALLS','LOC_BUILDING_WALLS_NAME','TECH_MASONRY',NULL,80,-1,-1,0,'DISTRICT_CITY_CENTER',NULL,'LOC_BUILDING_WALLS_DESCRIPTION',0,0,50,0,0,NULL,NULL,0,0,NULL,0,1,0,NULL,1,NULL,0,0,0,0,'NO_ERA',0,0,0,0,0,NULL,NULL,0,'ADVISOR_GENERIC');
DELETE FROM Buildings WHERE BuildingType ='BUILDING_WALLS';
UPDATE BuildingPrereqs SET PrereqBuilding ='BUILDING_ANCIENT_WALLS' WHERE PrereqBuilding ='BUILDING_WALLS';
UPDATE StartingBuildings SET Building ='BUILDING_ANCIENT_WALLS' WHERE Building ='BUILDING_WALLS';
UPDATE ModifierArguments SET Value ='BUILDING_ANCIENT_WALLS' WHERE Value ='BUILDING_WALLS';
--*/

/* Remove Civil Engineering */ 
/*
DELETE FROM Civics WHERE CivicType = 'CIVIC_CIVIL_ENGINEERING';
DELETE FROM CivicPrereqs WHERE Civic = 'CIVIC_CIVIL_ENGINEERING' or PrereqCivic = 'CIVIC_CIVIL_ENGINEERING';
DELETE FROM CivicModifiers WHERE CivicType = 'CIVIC_CIVIL_ENGINEERING';
DELETE FROM Boosts WHERE CivicType = 'CIVIC_CIVIL_ENGINEERING';
DELETE FROM AiFavoredItems WHERE Item = 'CIVIC_CIVIL_ENGINEERING';

UPDATE Improvement_ValidTerrains SET PrereqCivic = NULL, PrereqTech = 'TECH_ENGINEERING' WHERE PrereqCivic ='CIVIC_CIVIL_ENGINEERING';
UPDATE Policies SET PrereqCivic = 'CIVIC_NATIONALISM' WHERE PolicyType= 'POLICY_PUBLIC_WORKS';
UPDATE Policies SET PrereqCivic = 'CIVIC_URBANIZATION' WHERE PolicyType= 'POLICY_SKYSCRAPERS';
UPDATE Units SET ObsoleteCivic = NULL WHERE ObsoleteCivic ='CIVIC_CIVIL_ENGINEERING';
--*/

/* Reduce Ranged Attack Value */
/*
INSERT INTO GameModifiers
(	ModifierId							)	VALUES
(	'GAME_REDUCE_CITY_RANGED_STRIKE'	);

INSERT INTO Modifiers
(	ModifierId,							ModifierType,									RunOnce,	Permanent,	SubjectRequirementSetId,	OwnerRequirementSetId	)	VALUES
(	'GAME_REDUCE_CITY_RANGED_STRIKE',	'MODIFIER_PLAYER_CITIES_ADJUST_RANGED_STRIKE',	'0',		'0',		NULL,						NULL					);

INSERT INTO ModifierArguments
(	ModifierId,							Name,			Value	)	VALUES
(	'GAME_REDUCE_CITY_RANGED_STRIKE',	'Amount',		'-20'	);

*/

/*
UPDATE GlobalParameters SET Value = -1		WHERE Name = 'COMBAT_CITY_RANGED_DAMAGE_THRESHOLD';	-- default = 50
UPDATE GlobalParameters SET Value = 0		WHERE Name = 'COMBAT_MINIMUM_CITY_STRIKE_STRENGTH';	-- default = 3

UPDATE Districts SET HitPoints = 50		WHERE DistrictType = 'DISTRICT_CITY_CENTER';	-- default = 200

UPDATE Buildings SET OuterDefenseHitPoints ='0';
--*/
-----------------------------------------------
-- AI test
-----------------------------------------------
/*
UPDATE AiOperationTeams SET InitialStrengthAdvantage ='-1', OngoingStrengthAdvantage ='-1' WHERE TeamName LIKE '%City Attack%';
UPDATE AiOperationDefs SET MinOddsOfSuccess = '0';
--*/
-----------------------------------------------
-- Warmonger test
-----------------------------------------------

UPDATE Eras SET WarmongerPoints = 0 	WHERE EraType='ERA_ANCIENT'; 		-- Default = 0
UPDATE Eras SET WarmongerPoints = 0 	WHERE EraType='ERA_CLASSICAL';  	-- Default = 4
UPDATE Eras SET WarmongerPoints = 1 	WHERE EraType='ERA_MEDIEVAL';  		-- Default = 8
UPDATE Eras SET WarmongerPoints = 4 	WHERE EraType='ERA_RENAISSANCE';  	-- Default = 12
UPDATE Eras SET WarmongerPoints = 6 	WHERE EraType='ERA_INDUSTRIAL';  	-- Default = 18
UPDATE Eras SET WarmongerPoints = 8 	WHERE EraType='ERA_MODERN';  		-- Default = 24
UPDATE Eras SET WarmongerPoints = 16 	WHERE EraType='ERA_ATOMIC';  		-- Default = 24
UPDATE Eras SET WarmongerPoints = 16 	WHERE EraType='ERA_INFORMATION';  	-- Default = 24
	

UPDATE DiplomaticActions SET WarmongerPercent = 50 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_FORMAL_WAR'; 		-- Default = 100
UPDATE DiplomaticActions SET WarmongerPercent = 35 	WHERE DiplomaticActionType='DIPLOACTION_JOINT_WAR'; 				-- Default = 100
UPDATE DiplomaticActions SET WarmongerPercent = 150	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_SURPRISE_WAR'; 		-- Default = 150
UPDATE DiplomaticActions SET WarmongerPercent = 35 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_HOLY_WAR';			-- Default = 50
UPDATE DiplomaticActions SET WarmongerPercent = 0 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_LIBERATION_WAR';	-- Default = 0
UPDATE DiplomaticActions SET WarmongerPercent = 0 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_RECONQUEST_WAR'; 	-- Default = 0
UPDATE DiplomaticActions SET WarmongerPercent = 0 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_PROTECTORATE_WAR'; 	-- Default = 0
UPDATE DiplomaticActions SET WarmongerPercent = 35 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_COLONIAL_WAR'; 		-- Default = 50
UPDATE DiplomaticActions SET WarmongerPercent = 50 	WHERE DiplomaticActionType='DIPLOACTION_DECLARE_TERRITORIAL_WAR'; 	-- Default = 75


UPDATE GlobalParameters SET Value = 15 		WHERE Name='WARMONGER_CITY_PERCENT_OF_DOW'; 				-- Default = 50
UPDATE GlobalParameters SET Value = 50 		WHERE Name='WARMONGER_FINAL_MAJOR_CITY_MULTIPLIER'; 		-- Default = 200
UPDATE GlobalParameters SET Value = 100		WHERE Name='WARMONGER_FINAL_MINOR_CITY_MULTIPLIER'; 		-- Default = 100
UPDATE GlobalParameters SET Value = 50 		WHERE Name='DIPLOMACY_WARMONGER_POINT_PERCENT_DECAY'; 		-- Default = 50
UPDATE GlobalParameters SET Value = 32 		WHERE Name='WARMONGER_LIBERATE_POINTS'; 					-- Default = 32
UPDATE GlobalParameters SET Value = 200 	WHERE Name='WARMONGER_RAZE_PENALTY_PERCENT'; 				-- Default = 200
--UPDATE GlobalParameters SET Value = -100	WHERE Name='WARMONGER_STOP_OCCUPYING_REFUND_PERCENT';		-- Default = 100
--*/